# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .task import Task

__all__ = ["TaskListResponse"]

TaskListResponse: TypeAlias = List[Task]
