# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["TaskStartManualSessionParams"]


class TaskStartManualSessionParams(TypedDict, total=False):
    use_proxy: bool
    """If true, spawn the browser session using a proxy."""
